# -*- coding: utf-8 -*-
"""
Created on Fri May 20 15:23:05 2022

@author: oriol
"""

import pandas as pd
country_list = [
 ('Albania', 'AL'),
 ('Algeria', 'DZ'),
 ('Angola', 'AO'),
 ('Argentina', 'AR'),
 ('Australia', 'AU'),
 ('Austria', 'AT'),
 ('Azerbaijan', 'AZ'),
 ('Bangladesh', 'BD'),
 ('Belarus', 'BY'),
 ('Belgium', 'BE'),
 ('Bolivia', 'BO'),
 ('Bosnia And Herzegovina', 'BA'),
 ('Brazil', 'BR'),
 ('Bulgaria', 'BG'),
 ('Cambodia', 'KH'),
 ('Canada', 'CA'),
 ('Chile', 'CL'),
 ('China', 'CN'),
 ('Colombia', 'CO'),
 ('Costa Rica', 'CR'),
 ('Croatia', 'HR'),
 ('Cyprus', 'CY'),
 ('Czechia', 'CZ'),
 ('Democratic Republic Of Congo', 'CD'),
 ('Denmark', 'DK'),
 ('Dominican Republic', 'DO'),
 ('Ecuador', 'EC'),
 ('Egypt', 'EG'),
 ('El Salvador', 'SV'),
 ('Estonia', 'EE'),
 ('Ethiopia', 'ET'),
 ('European Union', 'EU'),
 ('Finland', 'FI'),
 ('France', 'FR'),
 ('Germany', 'DE'),
 ('Ghana', 'GH'),
 ('Greece', 'GR'),
 ('Guatemala', 'GT'),
 ('Honduras', 'HN'),
 ('Hong Kong', 'HK'),
 ('Hungary', 'HU'),
 ('India', 'IN'),
 ('Indonesia', 'ID'),
 ('Iran', 'IR'),
 ('Iraq', 'IQ'),
 ('Ireland', 'IE'),
 ('Israel', 'IL'),
 ('Italy', 'IT'),
 ('Japan', 'JP'),
 ('Jordan', 'JO'),
 ('Kazakhstan', 'KZ'),
 ('Kenya', 'KE'),
 ('Kuwait', 'KW'),
 ('Kyrgyzstan', 'KG'),
 ('Laos', 'LA'),
 ('Latvia', 'LV'),
 ('Lebanon', 'LB'),
 ('Libya', 'LY'),
 ('Lithuania', 'LT'),
 ('Luxembourg', 'LU'),
 ('Macao', 'MO'),
 ('Malaysia', 'MY'),
 ('Mexico', 'MX'),
 ('Mongolia', 'MN'),
 ('Morocco', 'MA'),
 ('Myanmar', 'MM'),
 ('Nepal', 'NP'),
 ('Netherlands', 'NL'),
 ('New Zealand', 'NZ'),
 ('Nicaragua', 'NI'),
 ('Nigeria', 'NG'),
 ('Norway', 'NO'),
 ('Oman', 'OM'),
 ('Pakistan', 'PK'),
 ('Panama', 'PA'),
 ('Paraguay', 'PY'),
 ('Peru', 'PE'),
 ('Philippines', 'PH'),
 ('Poland', 'PL'),
 ('Portugal', 'PT'),
 ('Qatar', 'QA'),
 ('Romania', 'RO'),
 ('Russian Federation', 'RU'),
 ('Saudi Arabia', 'SA'),
 ('Senegal', 'SN'),
 ('Serbia', 'RS'),
 ('Singapore', 'SG'),
 ('Slovakia', 'SK'),
 ('Slovenia', 'SI'),
 ('South Africa', 'ZA'),
 ('South Korea', 'KR'),
 ('Spain', 'ES'),
 ('Sri Lanka', 'LK'),
 ('Sudan', 'SD'),
 ('Sweden', 'SE'),
 ('Switzerland', 'CH'),
 ('Taiwan', 'TW'),
 ('Tajikistan', 'TJ'),
 ('Tanzania', 'TZ'),
 ('Thailand', 'TH'),
 ('Tunisia', 'TN'),
 ('Turkey', 'TR'),
 ('Turkmenistan', 'TM'),
 ('Ukraine', 'UA'),
 ('United Arab Emirates', 'AE'),
 ('United Kingdom', 'UK'),
 ('United States', 'US'),
 ('Uruguay', 'UY'),
 ('Uzbekistan', 'UZ'),
 ('Venezuela', 'VE'),
 ('Vietnam', 'VN')]

country_df = pd.DataFrame(country_list, columns=['name', 'iso2'])

country_groups = {
'Africa': ['DZ', 'AO', 'CD', 'EG', 'ET', 'GH', 'KE', 'LY', 'MA', 'NG', 'SN', 'ZA', 'SD', 'TZ', 'TN'],
'Central Asia': ['AZ', 'KZ', 'KG', 'MN', 'TJ', 'TM', 'UZ'],
'East Asia': ['CN', 'HK', 'JP', 'KR', 'MO', 'TW'],
'Europe': ['AL', 'AT', 'BY', 'BE', 'BA', 'BG', 'HR', 'CY', 'CZ', 'DK', 'EE', 'FI', 'FR', 'DE', 'GR', 'HU', 'IE', 'IT', 'LV', 'LT', 'LU', 'NL', 'NO', 'PL', 'PT', 'RO', 'RU', 'RS', 'SK', 'SI', 'ES', 'SE', 'CH', 'TR', 'UA', 'EU', 'UK'],
'G20': ['AR', 'AU', 'BR', 'CA', 'CN', 'FR', 'DE', 'IN', 'ID', 'IT', 'JP', 'KR', 'MX', 'RU', 'SA', 'ZA', 'TR', 'US', 'EU', 'UK'],
'Latin America': ['AR', 'BO', 'BR', 'CL', 'CO', 'CR', 'DO', 'EC', 'SV', 'GT', 'HN', 'NI', 'PA', 'PY', 'PE', 'UY', 'VE'],
'Middle East': ['IR', 'IQ', 'IL', 'JO', 'KW', 'LB', 'OM', 'QA', 'SA', 'AE'],
'North America': ['CA', 'MX', 'US'],
'Oceania': ['AU', 'NZ'],
'South Asia': ['BD', 'IN', 'NP', 'PK', 'LK'],
'Southeast Asia': ['KH', 'ID', 'LA', 'MY', 'MM', 'PH', 'SG', 'TH', 'VN']
}



# -*- coding: utf-8 -*-
"""
Created on Fri May 20 12:30:58 2022

@author: oriol
"""

import pandas as pd
from prognosis.helper import get
from prognosis.com import topic_tickers


class Country():
    def __init__(self, country_code):
        self.country_code = country_code

    def get_group(self, name, **k):

        codes = [(x % self.country_code) +
                 (('~T%s' % k.get('transform')) if k.get('transform') else '')
                 for x in topic_tickers[name]]
        return get(codes)

    def national_accounts(self, **k):
        """
        RGDP: Real gross domestic product
        RPRC: Real private consumption
        RPUC: Real public sector consumption
        RGFCF: Real gross fixed capital formation
        REXP: Real exports
        RIMP: Real imports

        Note: Real refers to inflation adjusted indicators
        """
        if k.get('nominal') is True:
            return self.get_group('national_accounts_nominal', **k)
        return self.get_group('national_accounts', **k)

    def prices(self, **k):
        return self.get_group('prices', **k)

    def monthly_trade(self, **k):
        return self.get_group('monthly_trade', **k)

    def government_accounts(self, **k):
        return self.get_group('government', **k)

    def yield_curve(self, **k):
        return self.get_group('yield_curve', **k)

    def retail_sales(self, **k):
        return self.get_group('retail_sales', **k)

    def ip(self, **k):
        return self.get_group('ip', **k)

    def energy(self, **k):
        """
        OILPROD: Oil production, thousands barrels per day
        OILDEM: Oil demand, thousands barrels per day
        GASODEM: Gasoline demand, thousands barrels per day
        GASOPROD: Gasoline production, thousands barrels per day
        GASDEM: Gas demand, millions of cubic meters per month
        GASPROD: Gas production, millions of cubic meters per month
        """
        return self.get_group('energy', **k)



# -*- coding: utf-8 -*-
"""
Created on Mon May 23 14:09:46 2022

@author: oriol
"""

import pandas as pd
import requests
from io import BytesIO

domain = 'https://www.econdb.com'


def get_available_widgets():
    return requests.post(
        domain + '/widgets/',
        json={'path': 'prognosis', 'args': []}).json()


def get_widget_options(widget_name):
    return requests.get(
        '%s/widgets/%s/options/' % (domain, widget_name)).json()


def get_widget_data(widget_name, opts):
    buff = BytesIO(requests.get(
        '%s/widgets/%s/data/' % (domain, widget_name),
        params={'format': 'csv', **opts}).content)
    buff.seek(0)
    df = pd.read_csv(buff)
    buff.close()
    return df



# -*- coding: utf-8 -*-
"""
Created on Fri May 20 16:07:36 2022

@author: oriol
"""

from prognosis.helper import get
from prognosis.com import topic_df, country_groups, country_df


topics = topic_df['code'].tolist()


class CountryGroup():
    def __init__(self, country_list):
        if isinstance(country_list, str):
            self.country_list = country_groups[country_list]
        else:
            assert isinstance(country_list, list)
            countries = country_df["iso2"].values
            for country in country_list:
                if not country in countries:
                    raise Exception("%s does not exist" % country)
            self.country_list = country_list

    def get_topic(self, name):
        assert name in topics, 'Choose among %s' % str(topics)
        codes = [name+x for x in self.country_list]
        return get(codes)



# -*- coding: utf-8 -*-
"""
Created on Fri May 20 16:08:29 2022

@author: oriol
"""
import pandas as pd
topic_tickers = {
    'national_accounts':
        ['RGDP%s', 'RPRC%s', 'RPUC%s', 'RGFCF%s', 'REXP%s','RIMP%s'],
    'national_accounts_nominal':
        ['GDP%s', 'PRC%s', 'PUC%s', 'GFCF%s', 'EXP%s','IMP%s'],
    'prices': ['CPI%s', 'PPI%s'],
    'government': ['GSPE%s', 'GREV%s', 'GBAL%s', 'GDEBT%s'],
    'monthly_trade': ['EXPMON%s', 'IMPMON%s'],
    'yield_curve': ['M3YD%s', 'Y10YD%s'],
    'retail_sales': ['RETA%s'],
    'ip': ['IP%s'],
    'energy':
        ['OILPROD%s', 'OILDEM%s', 'GASODEM%s', 'GASOPROD%s', 'GASDEM%s',
         'GASPROD%s'],
}


topic_df = pd.DataFrame([
 ('GDP', 'Gross domestic product'),
 ('PRC', 'Private consumption'),
 ('PUC', 'Public consumption'),
 ('CON', 'Total consumption'),
 ('GCF', 'Gross capital formation'),
 ('GFCF', 'Gross fixed capital formation'),
 ('CI', 'Change in inventories'),
 ('CBAL', 'Commercial balance (goods + services)'),
 ('EXP', 'Exports of goods and services'),
 ('IMP', 'Imports of goods and services'),
 ('PI', 'Personal income'),
 ('RGDP', 'Real gross domestic product'),
 ('RPRC', 'Real private consumption'),
 ('RPUC', 'Real public consumption'),
 ('RCON', 'Real total consumption'),
 ('RGCF', 'Real gross capital formation'),
 ('RGFCF', 'Real gross fixed capital formation'),
 ('RCI', 'Real change in inventories'),
 ('REXP', 'Real exports of goods and services'),
 ('RIMP', 'Real imports of goods and services'),
 ('GDPPC', 'GDP per capita'),
 ('RGDPPC', 'Real GDP per capita'),
 ('GDPD', 'GDP (current US dollars)'),
 ('GDPDEF', 'GDP deflator'),
 ('CPI', 'Consumer price index'),
 ('CORE', 'Core consumer price index'),
 ('PPI', 'Producer price index'),
 ('URATE', 'Unemployment'),
 ('JVR', 'Job vacancy rate'),
 ('JQR', 'Job quits rate'),
 ('JLR', 'Job layoffs rate'),
 ('JHR', 'Job hires rate'),
 ('WAGE', 'Wages/Earnings'),
 ('WAGEMAN', 'Hourly wage manufacturing'),
 ('EMP', 'Total employment'),
 ('ACPOP', 'Active population'),
 ('PAY', 'Total payroll'),
 ('EMRATIO', 'Employment to working age population'),
 ('PART', 'Participation rate'),
 ('CLAIMS', 'Weekly unemployment insurance claims'),
 ('RETA', 'Retail trade'),
 ('IP', 'Industrial production'),
 ('CP', 'Construction production'),
 ('INVER', 'Investment rate'),
 ('SENT', 'Sentiment index'),
 ('CONF', 'Consumer confidence index'),
 ('UTIL', 'Utilization rate'),
 ('DWPE', 'Dwelling permits'),
 ('NFCI', 'Non-financial corporations investment rate'),
 ('CAR', 'Passenger car sales'),
 ('ELE', 'Production electricity'),
 ('ARIV', 'Tourist arrivals'),
 ('OIL', 'Oil production'),
 ('MANU', 'Manufacturing production'),
 ('CLI', 'OECD CLI'),
 ('TB', 'Trade balance'),
 ('NY', 'Net income from abroad (Primary Income)'),
 ('NCT', 'Net current transfers (Secondary Income)'),
 ('CA', 'Current account balance'),
 ('KA', 'Capital account'),
 ('CKA', 'Net foreign investment'),
 ('IIPA', 'International investment position: Assets'),
 ('IIPL', 'International investment position: Liabilities'),
 ('NIIP', 'Net international investment position'),
 ('EXPMON', 'Monthly exports'),
 ('IMPMON', 'Monthly imports'),
 ('GBAL', 'Government balance'),
 ('GSPE', 'General government total expenditure'),
 ('GREV', 'General government total revenue'),
 ('GDEBT', 'Government debt'),
 ('GDEBTN', 'Government net debt'),
 ('POP', 'Population'),
 ('HHS', 'Household saving'),
 ('HHDIR', 'Household debt to income ratio'),
 ('HOU', 'House price'),
 ('TFRT', 'Fertility rate'),
 ('LE00', 'Life expectancy at birth'),
 ('CRED', 'Domestic credit'),
 ('NFCLOAN', 'Lending to non-financial corporations'),
 ('PRIDEBT', 'Private debt'),
 ('NPL', 'Non performing loans'),
 ('MB', 'Monetary base'),
 ('M3', 'Money supply'),
 ('Y10YD', 'Long term yield'),
 ('M3YD', '3 month yield'),
 ('IBD1', 'Interbank lending overnight rate'),
 ('POLIR', 'Policy rate - short term'),
 ('XUSD', 'Exchange rate v dollar'),
 ('SEI', 'Stock exchange index'),
 ('REER', 'Real effective exchange rate'),
 ('EQYCAP', 'Market capitalization'),
 ('OILPROD', 'Oil production'),
 ('OILDEM', 'Oil demand'),
 ('GASPROD', 'Gas production'),
 ('GASDEM', 'Gas demand'),
 ('GASOPROD', 'Gasoline production'),
 ('GASODEM', 'Gasoline demand')
     ], columns=['code', 'name'])
